@@ -59,7 +59,7 @@ public:
   /// \param DasherScreen Pointer to the CDasherScreen object used to do rendering
   CDasherView(CEventHandler * pEventHandler, CSettingsStore * pSettingsStore, CDasherScreen * DasherScreen);
 
-  virtual ~ CDasherView() {
+  virtual ~CDasherView() {
   }
   ///
   /// Event handler
@@ -130,6 +130,8 @@ public:
   /// Drawing more complex structures, generally implemented by derived class
   /// @{
 
+  void RenderModel(CDasherModel *pModel);
+
   /// Renders Dasher with mouse-dependent items
   /// \todo Clarify relationship between Render functions and probably only expose one
   virtual bool Render(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, bool bRedrawDisplay, std::vector<std::pair<myint,bool> >* pvGameTargetY);
@@ -159,7 +161,7 @@ public:
 
   /// Draw a polyarrow
 
-  void DasherPolyarrow(myint * x, myint * y, int n, int iWidth, int iColour);
+  void DasherPolyarrow(myint * x, myint * y, int n, int iWidth, int iColour, double dArrowSizeFactor = 0.7071);
 
   ///
   /// Draw a polygon specified in Dasher co-ordinates
