@@ -1,4 +1,6 @@
-#include "config.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 
 #include <cstring>
 
@@ -252,7 +254,7 @@ dasher_main_finalize(GObject *pObject) {
 
   gtk_widget_destroy(pPrivate->pMainWindow);
 
-  /* TDO: Do we need to take down anything else? */
+  /* TODO: Do we need to take down anything else? */
 }
 
 /* Public methods */
@@ -467,6 +469,10 @@ dasher_main_load_interface(DasherMain *pSelf) {
     pPrivate->pPrefXML = (GladeXML *) g_object_ref(pPrivate->pGladeXML);
   }
 
+  // XXX PRLW: Hide the Help Contents as there is no handler to display help.
+  // #575365
+  gtk_widget_hide(glade_xml_get_widget(pPrivate->pGladeXML, "menu_command_help"));
+
   // Save the details of some of the widgets for later
   //  pPrivate->pActionPane = glade_xml_get_widget(pPrivate->pGladeXML, "vbox39");
   pPrivate->pBufferView = glade_xml_get_widget(pPrivate->pGladeXML, "the_text_view");
@@ -534,16 +540,16 @@ dasher_main_load_interface(DasherMain *pSelf) {
   g_object_ref(options_menu);
   g_object_ref(help_menu);
 
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem4")));
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "options1")));
-  gtk_menu_item_remove_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem7")));
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem4")), NULL);
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "options1")), NULL);
+  gtk_menu_item_set_submenu(GTK_MENU_ITEM(glade_xml_get_widget(pPrivate->pGladeXML, "menuitem7")), NULL);
 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(file_menu_item),file_menu);
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(options_menu_item),options_menu); 
   gtk_menu_item_set_submenu(GTK_MENU_ITEM(help_menu_item),help_menu);
-  gtk_menu_append(main_menu, file_menu_item);
-  gtk_menu_append(main_menu, options_menu_item);
-  gtk_menu_append(main_menu, help_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, file_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, options_menu_item);
+  gtk_menu_shell_append((GtkMenuShell *)main_menu, help_menu_item); 
 
   g_object_unref(file_menu);
   g_object_unref(options_menu);
@@ -988,19 +994,15 @@ dasher_main_set_window_title(DasherMain *pSelf) {
   const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
 
   // Note to translators: This is the name of the dasher program as it appears
-  // in a window title without a file.
+  // in a window title.
   gchar * dasher = _("Dasher");
   if(szFilename == 0) {
     gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), dasher);
   }
   else {
-    // Note to translators: This is a format string for the name of the dasher
-    // program as it appears in a window, %s will be the filename.
-    gchar * titleFormat = _("Dasher - %s");
-    int len = strlen(szFilename);
-    gchar title[len+strlen(titleFormat)];
-    snprintf(title, sizeof(title), titleFormat, szFilename);
+    gchar *title = g_strdup_printf("%s - %s", dasher, szFilename);
     gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), title);
+    g_free (title);
   }
 }
 
@@ -1076,6 +1078,8 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
   GtkWidget *pDialogue = NULL;
 
   if(dasher_editor_file_changed(pPrivate->pEditor)) {
+// XXX PRLW: Just open the save dialogue box.
+#if 0
     const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
 
     if(szFilename) {
@@ -1085,10 +1089,13 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 					 szFilename);
     }
     else {
+#endif
       pDialogue = gtk_message_dialog_new(GTK_WINDOW(pPrivate->pMainWindow), GTK_DIALOG_MODAL, 
 					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, 
 					 _("Do you want to save your changes?\n\nYour changes will be lost if you don't save them."));
+#if 0
     }
+#endif
 
     gtk_dialog_add_buttons(GTK_DIALOG(pDialogue), 
 			   _("Don't save"), GTK_RESPONSE_REJECT,
@@ -1098,27 +1105,34 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 
     switch (gtk_dialog_run(GTK_DIALOG(pDialogue))) {
     case GTK_RESPONSE_REJECT:
-      //      write_to_file(); // FIXME - REIMPLEMENT
       gtk_main_quit();
       break;
     case GTK_RESPONSE_CANCEL:
       gtk_widget_destroy(GTK_WIDGET(pDialogue));
       break;
     case GTK_RESPONSE_ACCEPT:
-      gtk_widget_destroy(GTK_WIDGET(pDialogue));
-      //      write_to_file(); // FIXME - REIMPLEMENT
-      //      save_file_and_quit(NULL, NULL);
+      dasher_editor_command(pPrivate->pEditor, "save");
+      gtk_main_quit();
+      break;
     }
   }
   else {
-    // It should be noted that write_to_file merely saves the new text to the training
-    // file rather than saving it to a file of the user's choice
+	pDialogue = gtk_message_dialog_new(GTK_WINDOW(pPrivate->pMainWindow), GTK_DIALOG_MODAL, 
+					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, 
+					 _("Are you sure you wish to quit?"));
 
-    // FIXME - REIMPLEMENT
+    	gtk_dialog_add_buttons(GTK_DIALOG(pDialogue), 
+			   _("Don't quit"), GTK_RESPONSE_REJECT,
+			   _("Quit"), GTK_RESPONSE_ACCEPT, 
+			   NULL);
 
-    //    write_to_file();
-
-    gtk_main_quit();
+    switch (gtk_dialog_run(GTK_DIALOG(pDialogue))) {
+    case GTK_RESPONSE_REJECT:
+	gtk_widget_destroy(GTK_WIDGET(pDialogue));
+      break;
+    case GTK_RESPONSE_ACCEPT:
+      gtk_main_quit();
+    }
   }
 }
 
@@ -1158,19 +1172,22 @@ dasher_main_command_about(DasherMain *pSelf) {
   const gchar *authors[] = {
     "Chris Ball",
     "Ignas Budvytis",
+    "Peter Conlon",
     "Phil Cowans",
     "Frederik Eaton",
     "Behdad Esfahbod",
     "Matthew Garrett",
     "Chris Hack",
+    "Takashi Kaburagi",
+    "Sega Kazue",
+    "Alan Lawrence",
     "David MacKay",
     "Iain Murray",
-    "Sega Kazue",
-    "Takashi Kaburagi",
     "Martijn van Veen",
     "Keith Vertanen",
     "Hanna Wallach",
     "David Ward",
+    "Patrick Welche",
     "Brian Williams",
     "Seb Wills",
     "Will Zou",
@@ -1189,7 +1206,7 @@ dasher_main_command_about(DasherMain *pSelf) {
   gtk_show_about_dialog(GTK_WINDOW(pPrivate->pMainWindow),
 			"authors", authors,
 			"comments", _("Dasher is a predictive text entry application"), 
-			"copyright", "Copyright \xC2\xA9 1998-2007 The Dasher Project", 
+			"copyright", "Copyright \xC2\xA9 1998-2009 The Dasher Project", 
 			"documenters", documenters,
 			"license", "GPL 2+",
 			"logo-icon-name", "dasher",
@@ -1252,7 +1269,7 @@ static gboolean
 dasher_main_speed_changed(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
   
-  int iNewValue( static_cast<int>(round(gtk_spin_button_get_value_as_float(GTK_SPIN_BUTTON(pPrivate->pSpeedBox)) * 100)));
+  int iNewValue( static_cast<int>(round(gtk_spin_button_get_value(GTK_SPIN_BUTTON(pPrivate->pSpeedBox)) * 100)));
   
   if(dasher_app_settings_get_long(pPrivate->pAppSettings, LP_MAX_BITRATE) != iNewValue)
     dasher_app_settings_set_long(pPrivate->pAppSettings, LP_MAX_BITRATE, iNewValue);
@@ -1278,7 +1295,7 @@ dasher_main_alphabet_combo_changed(DasherMain *pSelf) {
     else 
       dasher_app_settings_set_string(pPrivate->pAppSettings, SP_ALPHABET_ID, szSelected);
 
-    free(szSelected);
+    g_free(szSelected);
   }
 }
 
